@@ -37,101 +37,101 @@ functions:
     * Sugeno
     * ExpandKinteractive2Bit
     * ExpandKinteractive2Bit_m
-    * py_Shapley
-	* Banzhaf
-	* ShapleyMob
-	* BanzhafMob
-	* ConstructLambdaMeasure
-	* ConstructLambdaMeasureMob
-	* dualm(double
-	* dualmMob(double
-	* FuzzyMeasureFit
-	* FuzzyMeasureFitMob
-	* FuzzyMeasureFitKtolerant
-	* FuzzyMeasureFitLPKmaxitive
-	* FuzzyMeasureFitLPKinteractive
-	* FuzzyMeasureFitLPKinteractiveMaxChains
-	* FuzzyMeasureFitLPKinteractiveAutoK
-	* FuzzyMeasureFitLPKinteractiveMarginal
-	* FuzzyMeasureFitLPKinteractiveMarginalMaxChain
-	* FuzzyMeasureFitLP
-	* FuzzyMeasureFitLPMob
-	* fittingOWA
-	* fittingWAM
-	* Interaction
-	* InteractionB
-	* InteractionMob
-	* InteractionBMob
-	* BipartitionShapleyIndex
-	* BipartitionBanzhafIndex
-	* BNonadditivityIndexMob
-	* NonadditivityIndex
-	* NonmodularityIndex
-	* NonmodularityIndexMob
-	* NonmodularityIndexKinteractive
-	* NonmodularityIndexMobkadditive
-	* Mobius
-	* Zeta
-	* dualMobKadd
-	* Shapley2addMob
-	* Banzhaf2addMob
-	* prepare_fm_sparse
-	* ShapleyMob_sparse
-	* BanzhafMob_sparse
-	* populate_fm_2add_sparse
-	* add_pair_sparse
-	* add_tuple_sparse
-	* populate_fm_2add_sparse_from2add
-	* expand_2add_full
-	* expand_sparse_full
-	* sparse_get_singletons
-	* Nonmodularityindex_sparse
-	* SizeArraykinteractive
-	* IsSubsetC
-	* IsElementC
-	* IsMeasureBalanced
-	* IsMeasureSelfdual
-	* IsMeasureSubadditive
-	* IsMeasureSubmodular
-	* IsMeasureSuperadditive
-	* IsMeasureSymmetric
-	* IsMeasureKMaxitive
-	* IsMeasureAdditiveMob
-	* IsMeasureBalancedMob
-	* IsMeasureSelfdualMob
+    * Shapley
+    * Banzhaf
+    * ShapleyMob
+    * BanzhafMob
+    * ConstructLambdaMeasure
+    * ConstructLambdaMeasureMob
+    * dualm
+    * dualmMob
+    * FuzzyMeasureFit
+    * FuzzyMeasureFitMob
+    * FuzzyMeasureFitKtolerant
+    * FuzzyMeasureFitLPKmaxitive
+    * FuzzyMeasureFitLPKinteractive
+    * FuzzyMeasureFitLPKinteractiveMaxChains
+    * FuzzyMeasureFitLPKinteractiveAutoK
+    * FuzzyMeasureFitLPKinteractiveMarginal
+    * FuzzyMeasureFitLPKinteractiveMarginalMaxChain
+    * FuzzyMeasureFitLP
+    * FuzzyMeasureFitLPMob
+    * fittingOWA
+    * fittingWAM
+    * Interaction
+    * InteractionB
+    * InteractionMob
+    * InteractionBMob
+    * BipartitionShapleyIndex
+    * BipartitionBanzhafIndex
+    * BNonadditivityIndexMob
+    * NonadditivityIndex
+    * NonmodularityIndex
+    * NonmodularityIndexMob
+    * NonmodularityIndexKinteractive
+    * NonmodularityIndexMobkadditive
+    * Mobius
+    * Zeta
+    * dualMobKadd
+    * Shapley2addMob
+    * Banzhaf2addMob
+    * prepare_fm_sparse
+    * ShapleyMob_sparse
+    * BanzhafMob_sparse
+    * populate_fm_2add_sparse
+    * add_pair_sparse
+    * add_tuple_sparse
+    * populate_fm_2add_sparse_from2add
+    * expand_2add_full
+    * expand_sparse_full
+    * sparse_get_singletons
+    * Nonmodularityindex_sparse
+    * SizeArraykinteractive
+    * IsSubsetC
+    * IsElementC
+    * IsMeasureBalanced
+    * IsMeasureSelfdual
+    * IsMeasureSubadditive
+    * IsMeasureSubmodular
+    * IsMeasureSuperadditive
+    * IsMeasureSymmetric
+    * IsMeasureKMaxitive
+    * IsMeasureAdditiveMob
+    * IsMeasureBalancedMob
+    * IsMeasureSelfdualMob
 	* IsMeasureSubadditiveMob
-	* IsMeasureSubmodularMob
-	* IsMeasureSuperadditiveMob
-	* IsMeasureSupermodularMob
-	* IsMeasureSymmetricMob
-	* IsMeasureKMaxitiveMob
-	* fm_arraysize
-	* generate_fm_minplus
-	* generate_fm_2additive_convex
-	* generate_fm_2additive_convex_withsomeindependent
-	* tuple_cardinality_sparse
-	* get_num_tuples(struct
-	* get_sizearray_tuples(struct
-	* is_inset_sparse
-	* is_subset_sparse
-	* sparse_get_pairs
-	* sparse_get_tuples
-	* generate_fm_2additive_convex_sparse
-	* generate_fm_kadditive_convex_sparse
-	* min_subset
-	* max_subset
-	* min_subsetC
-	* max_subsetNegC
-	* ChoquetKinter
-	* ChoquetMob
-	* Entropy
-	* Orness
-	* OWA
-	* WAM
-	* Choquet2addMob
-	* min_subset_sparse
-	* max_subset_sparse
-	* ChoquetMob_sparse
+    * IsMeasureSubmodularMob
+    * IsMeasureSuperadditiveMob
+    * IsMeasureSupermodularMob
+    * IsMeasureSymmetricMob
+    * IsMeasureKMaxitiveMob
+    * fm_arraysize
+    * generate_fm_minplus
+    * generate_fm_2additive_convex
+    * generate_fm_2additive_convex_withsomeindependent
+    * tuple_cardinality_sparse
+    * get_num_tuples(struct
+    * get_sizearray_tuples(struct
+    * is_inset_sparse
+    * is_subset_sparse
+    * sparse_get_pairs
+    * sparse_get_tuples
+    * generate_fm_2additive_convex_sparse
+    * generate_fm_kadditive_convex_sparse
+    * min_subset
+    * max_subset
+    * min_subsetC
+    * max_subsetNegC
+    * ChoquetKinter
+    * ChoquetMob
+    * Entropy
+    * Orness
+    * OWA
+    * WAM
+    * Choquet2addMob
+    * min_subset_sparse
+    * max_subset_sparse
+    * ChoquetMob_sparse
 """
 
 
@@ -298,7 +298,7 @@ def Sugeno( x, vb, env):
 # The python wrapper for all other py_ functions from wrapper.cpp
 ###
 
-# Generated python wrapper for:
+
 #    double py_min_subset(double* x, int n, int_64 S)
 def min_subset(x, n, S):
     trace( "double py_min_subset(double* x, int n, int_64 S)")
@@ -307,7 +307,7 @@ def min_subset(x, n, S):
     return yy
 
 
-# Generated python wrapper for:
+
 #    double py_max_subset(double* x, int n, int_64 S)
 def max_subset(x, n, S):
     trace( "double py_max_subset(double* x, int n, int_64 S)")
@@ -316,7 +316,7 @@ def max_subset(x, n, S):
     return yy
 
 
-# Generated python wrapper for:
+
 #    double py_min_subsetC(double* x, int n, int_64 S, struct fm_env* env)
 def min_subsetC(x, n, S, env):
     trace( "double py_min_subsetC(double* x, int n, int_64 S, struct fm_env* env)")
@@ -325,7 +325,7 @@ def min_subsetC(x, n, S, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    double py_max_subsetNegC(double* x, int n, int_64 S, struct fm_env* env)
 def max_subsetNegC(x, n, S, env):
     trace( "double py_max_subsetNegC(double* x, int n, int_64 S, struct fm_env* env)")
@@ -334,7 +334,7 @@ def max_subsetNegC(x, n, S, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_SizeArraykinteractive(int n, int k, struct fm_env* env)
 def SizeArraykinteractive(n, k, env):
     trace( "int py_SizeArraykinteractive(int n, int k, struct fm_env* env)")
@@ -342,7 +342,7 @@ def SizeArraykinteractive(n, k, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsSubsetC(int i, int j, struct fm_env* env)
 def IsSubsetC(i, j, env):
     trace( "int py_IsSubsetC(int i, int j, struct fm_env* env)")
@@ -350,7 +350,7 @@ def IsSubsetC(i, j, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsElementC(int i, int j, struct fm_env* env)
 def IsElementC(i, j, env):
     trace( "int py_IsElementC(int i, int j, struct fm_env* env)")
@@ -358,7 +358,7 @@ def IsElementC(i, j, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    void py_ExpandKinteractive2Bit(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize)
 def ExpandKinteractive2Bit(src, env, kint):
     trace( "void py_ExpandKinteractive2Bit(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize)")
@@ -369,7 +369,7 @@ def ExpandKinteractive2Bit(src, env, kint):
     return pout_destnp
 
 
-# Generated python wrapper for:
+
 #    void py_ExpandKinteractive2Bit_m(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize, double* out_VVC)
 def ExpandKinteractive2Bit_m(src, env, kint):
     trace( "void py_ExpandKinteractive2Bit_m(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize, double* out_VVC)")
@@ -381,7 +381,7 @@ def ExpandKinteractive2Bit_m(src, env, kint):
     return pout_destnp, pout_VVCnp
 
 
-# Generated python wrapper for:
+
 #    void py_Shapley(double* v, double* out_x, struct fm_env* env)
 def Shapley(v, env):
     trace( "void py_Shapley(double* v, double* out_x, struct fm_env* env)")
@@ -391,7 +391,7 @@ def Shapley(v, env):
     return pout_xnp
 
 
-# Generated python wrapper for:
+
 #    void py_Banzhaf(double* v, double* out_B, struct fm_env* env)
 def Banzhaf(v, env):
     trace( "void py_Banzhaf(double* v, double* out_B, struct fm_env* env)")
@@ -401,7 +401,7 @@ def Banzhaf(v, env):
     return pout_Bnp
 
 
-# Generated python wrapper for:
+
 #    void py_ShapleyMob(double* Mob, double* out_x, struct fm_env* env)
 def ShapleyMob(Mob, env):
     trace( "void py_ShapleyMob(double* Mob, double* out_x, struct fm_env* env)")
@@ -411,7 +411,7 @@ def ShapleyMob(Mob, env):
     return pout_xnp
 
 
-# Generated python wrapper for:
+
 #    void py_BanzhafMob(double* Mob, double* out_B, struct fm_env* env)
 def BanzhafMob(Mob, env):
     trace( "void py_BanzhafMob(double* Mob, double* out_B, struct fm_env* env)")
@@ -421,7 +421,7 @@ def BanzhafMob(Mob, env):
     return pout_Bnp
 
 
-# Generated python wrapper for:
+
 #    double py_ChoquetKinter(double* x, double* v, int kint, struct fm_env* env)
 def ChoquetKinter(x, v, kint, env):
     trace( "double py_ChoquetKinter(double* x, double* v, int kint, struct fm_env* env)")
@@ -431,7 +431,7 @@ def ChoquetKinter(x, v, kint, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    double py_ChoquetMob(double* x, double* Mob, struct fm_env* env)
 def ChoquetMob(x, Mob, env):
     trace( "double py_ChoquetMob(double* x, double* Mob, struct fm_env* env)")
@@ -441,7 +441,7 @@ def ChoquetMob(x, Mob, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    void py_ConstructLambdaMeasure(double* singletons, double* out_lambdax, double* out_v, struct fm_env* env)
 def ConstructLambdaMeasure(singletons, env):
     trace( "void py_ConstructLambdaMeasure(double* singletons, double* out_lambdax, double* out_v, struct fm_env* env)")
@@ -453,7 +453,7 @@ def ConstructLambdaMeasure(singletons, env):
     return pout_lambdaxnp, pout_vnp
 
 
-# Generated python wrapper for:
+
 #    void py_ConstructLambdaMeasureMob(double* singletons, double* out_lambdax, double* out_Mob, struct fm_env* env)
 def ConstructLambdaMeasureMob(singletons, env):
     trace( "void py_ConstructLambdaMeasureMob(double* singletons, double* out_lambdax, double* out_Mob, struct fm_env* env)")
@@ -465,7 +465,7 @@ def ConstructLambdaMeasureMob(singletons, env):
     return pout_lambdaxnp, pout_Mobnp
 
 
-# Generated python wrapper for:
+
 #    void py_dualm(double* v, double* out_w, struct fm_env* env)
 def dualm(v, env):
     trace( "void py_dualm(double* v, double* out_w, struct fm_env* env)")
@@ -475,7 +475,7 @@ def dualm(v, env):
     return pout_wnp
 
 
-# Generated python wrapper for:
+
 #    void py_dualmMob(double* v, double* out_w, struct fm_env* env)
 def dualmMob(v, env):
     trace( "void py_dualmMob(double* v, double* out_w, struct fm_env* env)")
@@ -485,7 +485,7 @@ def dualmMob(v, env):
     return pout_wnp
 
 
-# Generated python wrapper for:
+
 #    double py_Entropy(double* v, struct fm_env* env)
 def Entropy(v, env):
     trace( "double py_Entropy(double* v, struct fm_env* env)")
@@ -494,7 +494,7 @@ def Entropy(v, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    void py_FuzzyMeasureFit(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
 def FuzzyMeasureFit(datanum, additive, env, dataset = None):
     trace( "void py_FuzzyMeasureFit(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)")
@@ -505,7 +505,7 @@ def FuzzyMeasureFit(datanum, additive, env, dataset = None):
     return pout_vnp, dataset
 
 
-# Generated python wrapper for:
+
 #    void py_FuzzyMeasureFitMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
 def FuzzyMeasureFitMob(datanum, additive, env, dataset = None):
     trace( "void py_FuzzyMeasureFitMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)")
@@ -516,7 +516,7 @@ def FuzzyMeasureFitMob(datanum, additive, env, dataset = None):
     return pout_vnp, dataset
 
 
-# Generated python wrapper for:
+
 #    void py_FuzzyMeasureFitKtolerant(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
 def FuzzyMeasureFitKtolerant(datanum, additive, env, dataset = None):
     trace( "void py_FuzzyMeasureFitKtolerant(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)")
@@ -527,7 +527,7 @@ def FuzzyMeasureFitKtolerant(datanum, additive, env, dataset = None):
     return pout_vnp, dataset
 
 
-# Generated python wrapper for:
+
 #    void py_FuzzyMeasureFitLPKmaxitive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
 def FuzzyMeasureFitLPKmaxitive(datanum, additive, env, dataset = None):
     trace( "void py_FuzzyMeasureFitLPKmaxitive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)")
@@ -538,7 +538,7 @@ def FuzzyMeasureFitLPKmaxitive(datanum, additive, env, dataset = None):
     return pout_vnp, dataset
 
 
-# Generated python wrapper for:
+
 #    void py_FuzzyMeasureFitLPKinteractive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K)
 def FuzzyMeasureFitLPKinteractive(datanum, additive, env, K, dataset = None):
     trace( "void py_FuzzyMeasureFitLPKinteractive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K)")
@@ -550,7 +550,7 @@ def FuzzyMeasureFitLPKinteractive(datanum, additive, env, K, dataset = None):
     return pout_vnp, dataset
 
 
-# Generated python wrapper for:
+
 #    void py_FuzzyMeasureFitLPKinteractiveMaxChains(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K)
 def FuzzyMeasureFitLPKinteractiveMaxChains(datanum, additive, env, K, dataset = None):
     trace( "void py_FuzzyMeasureFitLPKinteractiveMaxChains(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset = None, double* K)")
@@ -562,7 +562,7 @@ def FuzzyMeasureFitLPKinteractiveMaxChains(datanum, additive, env, K, dataset =
     return pout_vnp, dataset
 
 
-# Generated python wrapper for:
+
 #    void py_FuzzyMeasureFitLPKinteractiveAutoK(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters)
 def FuzzyMeasureFitLPKinteractiveAutoK(datanum, additive, env, K, maxiters, dataset = None):
     trace( "void py_FuzzyMeasureFitLPKinteractiveAutoK(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters)")
@@ -575,7 +575,7 @@ def FuzzyMeasureFitLPKinteractiveAutoK(datanum, additive, env, K, maxiters, data
     return pout_vnp, dataset
 
 
-# Generated python wrapper for:
+
 #    void py_FuzzyMeasureFitLPKinteractiveMarginal(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int submod)
 def FuzzyMeasureFitLPKinteractiveMarginal(datanum, additive, env, K, submod, dataset = None):
     trace( "void py_FuzzyMeasureFitLPKinteractiveMarginal(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int submod)")
@@ -587,7 +587,7 @@ def FuzzyMeasureFitLPKinteractiveMarginal(datanum, additive, env, K, submod, dat
     return pout_vnp, dataset
 
 
-# Generated python wrapper for:
+
 #    void py_FuzzyMeasureFitLPKinteractiveMarginalMaxChain(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters, int submod)
 def FuzzyMeasureFitLPKinteractiveMarginalMaxChain(datanum, additive, env, K, maxiters, submod, dataset = None):
     trace( "void py_FuzzyMeasureFitLPKinteractiveMarginalMaxChain(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters, int submod)")
@@ -600,7 +600,7 @@ def FuzzyMeasureFitLPKinteractiveMarginalMaxChain(datanum, additive, env, K, max
     return pout_vnp, dataset
 
 
-# Generated python wrapper for:
+
 #    void py_FuzzyMeasureFitLP(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)
 def FuzzyMeasureFitLP(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset = None):
     trace( "void py_FuzzyMeasureFitLP(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)")
@@ -616,7 +616,7 @@ def FuzzyMeasureFitLP(datanum, additive, env, options, indexlow, indexhihg, opti
     return pout_vnp, dataset
 
 
-# Generated python wrapper for:
+
 #    void py_FuzzyMeasureFitLPMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)
 def FuzzyMeasureFitLPMob(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset = None):
     trace( "void py_FuzzyMeasureFitLPMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)")
@@ -632,7 +632,7 @@ def FuzzyMeasureFitLPMob(datanum, additive, env, options, indexlow, indexhihg, o
     return pout_vnp, dataset
 
 
-# Generated python wrapper for:
+
 #    void py_fittingOWA(int datanum, struct fm_env* env, double* out_v, double* dataset)
 def fittingOWA(datanum, env, dataset = None):
     trace( "void py_fittingOWA(int datanum, struct fm_env* env, double* out_v, double* dataset)")
@@ -643,7 +643,7 @@ def fittingOWA(datanum, env, dataset = None):
     return pout_vnp, dataset
 
 
-# Generated python wrapper for:
+
 #    void py_fittingWAM(int datanum, struct fm_env* env, double* out_v, double* dataset)
 def fittingWAM(datanum, env, dataset = None):
     trace( "void py_fittingWAM(int datanum, struct fm_env* env, double* out_v, double* dataset)")
@@ -655,7 +655,7 @@ def fittingWAM(datanum, env, dataset = None):
 
 
 
-# Generated python wrapper for:
+
 #    void py_Interaction(double* Mob, double* out_v, struct fm_env* env)
 def Interaction(Mob, env):
     trace( "void py_Interaction(double* Mob, double* out_v, struct fm_env* env)")
@@ -666,7 +666,7 @@ def Interaction(Mob, env):
     return pout_vnp
 
 
-# Generated python wrapper for:
+
 #    void py_InteractionB(double* Mob, double* out_v, struct fm_env* env)
 def InteractionB(Mob, env):
     trace( "void py_InteractionB(double* Mob, double* out_v, struct fm_env* env)")
@@ -677,7 +677,7 @@ def InteractionB(Mob, env):
     return pout_vnp
 
 
-# Generated python wrapper for:
+
 #    void py_InteractionMob(double* Mob, double* out_v, struct fm_env* env)
 def InteractionMob(Mob, env):
     trace( "void py_InteractionMob(double* Mob, double* out_v, struct fm_env* env)")
@@ -688,7 +688,7 @@ def InteractionMob(Mob, env):
     return pout_vnp
 
 
-# Generated python wrapper for:
+
 #    void py_InteractionBMob(double* Mob, double* out_v, struct fm_env* env)
 def InteractionBMob(Mob, env):
     trace( "void py_InteractionBMob(double* Mob, double* out_v, struct fm_env* env)")
@@ -698,7 +698,7 @@ def InteractionBMob(Mob, env):
     fm.py_InteractionBMob( pMob, pout_v, env)
     return pout_vnp
 
-# Generated python wrapper for:
+
 #    void py_BipartitionShapleyIndex(double* v, double* out_w, struct fm_env* env)
 def BipartitionShapleyIndex(v, env):
     trace( "void py_BipartitionShapleyIndex(double* v, double* out_w, struct fm_env* env)")
@@ -708,7 +708,7 @@ def BipartitionShapleyIndex(v, env):
     return pout_wnp
 
 
-# Generated python wrapper for:
+
 #    void py_BipartitionBanzhafIndex(double* v, double* out_w, struct fm_env* env)
 def BipartitionBanzhafIndex(v, env):
     trace( "void py_BipartitionBanzhafIndex(double* v, double* out_w, struct fm_env* env)")
@@ -718,7 +718,7 @@ def BipartitionBanzhafIndex(v, env):
     return pout_wnp
 
 
-# Generated python wrapper for:
+
 #    void py_BNonadditivityIndexMob(double* Mob, double* out_w, struct fm_env* env)
 def BNonadditivityIndexMob(Mob, env):
     trace( "void py_BNonadditivityIndexMob(double* Mob, double* out_w, struct fm_env* env)")
@@ -728,7 +728,7 @@ def BNonadditivityIndexMob(Mob, env):
     return pout_wnp
 
 
-# Generated python wrapper for:
+
 #    void py_NonadditivityIndex(double* v, double* out_w, struct fm_env* env)
 def NonadditivityIndex(v, env):
     trace( "void py_NonadditivityIndex(double* v, double* out_w, struct fm_env* env)")
@@ -738,7 +738,7 @@ def NonadditivityIndex(v, env):
     return pout_wnp
 
 
-# Generated python wrapper for:
+
 #    void py_NonmodularityIndex(double* v, double* out_w, struct fm_env* env)
 def NonmodularityIndex(v, env):
     trace( "void py_NonmodularityIndex(double* v, double* out_w, struct fm_env* env)")
@@ -748,7 +748,7 @@ def NonmodularityIndex(v, env):
     return pout_wnp
 
 
-# Generated python wrapper for:
+
 #    void py_NonmodularityIndexMob(double* Mob, double* out_w, struct fm_env* env)
 def NonmodularityIndexMob(Mob, env):
     trace( "void py_NonmodularityIndexMob(double* Mob, double* out_w, struct fm_env* env)")
@@ -758,7 +758,7 @@ def NonmodularityIndexMob(Mob, env):
     return pout_wnp
 
 
-# Generated python wrapper for:
+
 #    void py_NonmodularityIndexKinteractive(double* v, double* out_w, int kint,  struct fm_env* env)
 def NonmodularityIndexKinteractive(v, kint, env):
     trace( "void py_NonmodularityIndexKinteractive(double* v, double* out_w, int kint,  struct fm_env* env)")
@@ -768,7 +768,7 @@ def NonmodularityIndexKinteractive(v, kint, env):
     return pout_wnp
 
 
-# Generated python wrapper for:
+
 #    void py_NonmodularityIndexMobkadditive(double* Mob, double* out_w, int k,  struct fm_env* env)
 def NonmodularityIndexMobkadditive(Mob, k, env):
     trace( "void py_NonmodularityIndexMobkadditive(double* Mob, double* out_w, int k,  struct fm_env* env)")
@@ -778,7 +778,7 @@ def NonmodularityIndexMobkadditive(Mob, k, env):
     return pout_wnp
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureBalanced(double* v, struct fm_env* env)
 def IsMeasureBalanced(v, env):
     trace( "int py_IsMeasureBalanced(double* v, struct fm_env* env)")
@@ -787,7 +787,7 @@ def IsMeasureBalanced(v, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureSelfdual(double* v, struct fm_env* env)
 def IsMeasureSelfdual(v, env):
     trace( "int py_IsMeasureSelfdual(double* v, struct fm_env* env)")
@@ -796,7 +796,7 @@ def IsMeasureSelfdual(v, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureSubadditive(double* v, struct fm_env* env)
 def IsMeasureSubadditive(v, env):
     trace( "int py_IsMeasureSubadditive(double* v, struct fm_env* env)")
@@ -805,7 +805,7 @@ def IsMeasureSubadditive(v, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureSubmodular(double* v, struct fm_env* env)
 def IsMeasureSubmodular(v, env):
     trace( "int py_IsMeasureSubmodular(double* v, struct fm_env* env)")
@@ -814,7 +814,7 @@ def IsMeasureSubmodular(v, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureSuperadditive(double* v, struct fm_env* env)
 def IsMeasureSuperadditive(v, env):
     trace( "int py_IsMeasureSuperadditive(double* v, struct fm_env* env)")
@@ -823,7 +823,7 @@ def IsMeasureSuperadditive(v, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureSymmetric(double* v, struct fm_env* env)
 def IsMeasureSymmetric(v, env):
     trace( "int py_IsMeasureSymmetric(double* v, struct fm_env* env)")
@@ -832,7 +832,7 @@ def IsMeasureSymmetric(v, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureKMaxitive(double* v, struct fm_env* env)
 def IsMeasureKMaxitive(v, env):
     trace( "int py_IsMeasureKMaxitive(double* v, struct fm_env* env)")
@@ -841,7 +841,7 @@ def IsMeasureKMaxitive(v, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureAdditiveMob(double* Mob, struct fm_env* env)
 def IsMeasureAdditiveMob(Mob, env):
     trace( "int py_IsMeasureAdditiveMob(double* Mob, struct fm_env* env)")
@@ -850,7 +850,7 @@ def IsMeasureAdditiveMob(Mob, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureBalancedMob(double* Mob, struct fm_env* env)
 def IsMeasureBalancedMob(Mob, env):
     trace( "int py_IsMeasureBalancedMob(double* Mob, struct fm_env* env)")
@@ -859,7 +859,7 @@ def IsMeasureBalancedMob(Mob, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureSelfdualMob(double* Mob, struct fm_env* env)
 def IsMeasureSelfdualMob(Mob, env):
     trace( "int py_IsMeasureSelfdualMob(double* Mob, struct fm_env* env)")
@@ -868,7 +868,7 @@ def IsMeasureSelfdualMob(Mob, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureSubadditiveMob(double* Mob, struct fm_env* env)
 def IsMeasureSubadditiveMob(Mob, env):
     trace( "int py_IsMeasureSubadditiveMob(double* Mob, struct fm_env* env)")
@@ -877,7 +877,7 @@ def IsMeasureSubadditiveMob(Mob, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureSubmodularMob(double* Mob, struct fm_env* env)
 def IsMeasureSubmodularMob(Mob, env):
     trace( "int py_IsMeasureSubmodularMob(double* Mob, struct fm_env* env)")
@@ -886,7 +886,7 @@ def IsMeasureSubmodularMob(Mob, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureSuperadditiveMob(double* Mob, struct fm_env* env)
 def IsMeasureSuperadditiveMob(Mob, env):
     trace( "int py_IsMeasureSuperadditiveMob(double* Mob, struct fm_env* env)")
@@ -895,7 +895,7 @@ def IsMeasureSuperadditiveMob(Mob, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureSupermodularMob(double* Mob, struct fm_env* env)
 def IsMeasureSupermodularMob(Mob, env):
     trace( "int py_IsMeasureSupermodularMob(double* Mob, struct fm_env* env)")
@@ -904,7 +904,7 @@ def IsMeasureSupermodularMob(Mob, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureSymmetricMob(double* Mob, struct fm_env* env)
 def IsMeasureSymmetricMob(Mob, env):
     trace( "int py_IsMeasureSymmetricMob(double* Mob, struct fm_env* env)")
@@ -913,7 +913,7 @@ def IsMeasureSymmetricMob(Mob, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_IsMeasureKMaxitiveMob(double* Mob, struct fm_env* env)
 def IsMeasureKMaxitiveMob(Mob, env):
     trace( "int py_IsMeasureKMaxitiveMob(double* Mob, struct fm_env* env)")
@@ -922,7 +922,7 @@ def IsMeasureKMaxitiveMob(Mob, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    void py_Mobius(double* v, double* out_MobVal, struct fm_env* env)
 def Mobius(v, env):
     trace( "void py_Mobius(double* v, double* out_MobVal, struct fm_env* env)")
@@ -932,7 +932,7 @@ def Mobius(v, env):
     return pout_MobValnp
 
 
-# Generated python wrapper for:
+
 #    double py_Orness(double* Mob, struct fm_env* env)
 def Orness(Mob, env):
     trace( "double py_Orness(double* Mob, struct fm_env* env)")
@@ -941,7 +941,7 @@ def Orness(Mob, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    double py_OWA(double* x, double* v, struct fm_env* env)
 def OWA(x, v, env):
     trace( "double py_OWA(double* x, double* v, struct fm_env* env)")
@@ -951,7 +951,7 @@ def OWA(x, v, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    double py_WAM(double* x, double* v, struct fm_env* env)
 def WAM(x, v, env):
     trace( "double py_WAM(double* x, double* v, struct fm_env* env)")
@@ -961,7 +961,7 @@ def WAM(x, v, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    void py_Zeta(double* Mob, double* out_v, struct fm_env* env)
 def Zeta(Mob, env):
     trace( "void py_Zeta(double* Mob, double* out_v, struct fm_env* env)")
@@ -971,7 +971,7 @@ def Zeta(Mob, env):
     return pout_vnp
 
 
-# Generated python wrapper for:
+
 #    void py_dualMobKadd(int m, int length, int k, double* src, double* out_dest, struct fm_env* env)
 def dualMobKadd(k, src, env):
     trace( "void py_dualMobKadd(int m, int length, int k, double* src, double* out_dest, struct fm_env* env)")
@@ -982,7 +982,7 @@ def dualMobKadd(k, src, env):
     return pout_destnp, length
 
 
-# Generated python wrapper for:
+
 #    void py_Shapley2addMob(double* v, double* out_x, int n)
 def Shapley2addMob(v, n):
     trace( "void py_Shapley2addMob(double* v, double* out_x, int n)")
@@ -992,7 +992,7 @@ def Shapley2addMob(v, n):
     return pout_xnp
 
 
-# Generated python wrapper for:
+
 #    void py_Banzhaf2addMob(double* v, double* out_x, int n)
 def Banzhaf2addMob(v, n):
     trace( "void py_Banzhaf2addMob(double* v, double* out_x, int n)")
@@ -1002,7 +1002,7 @@ def Banzhaf2addMob(v, n):
     return pout_xnp
 
 
-# Generated python wrapper for:
+
 #    double py_Choquet2addMob(double* x, double* Mob, int n)
 def Choquet2addMob(x, Mob, n):
     trace( "double py_Choquet2addMob(double* x, double* Mob, int n)")
@@ -1012,7 +1012,7 @@ def Choquet2addMob(x, Mob, n):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_fm_arraysize(int n, int kint, struct fm_env* env)
 def fm_arraysize(n, kint, env):
     trace( "int py_fm_arraysize(int n, int kint, struct fm_env* env)")
@@ -1020,7 +1020,7 @@ def fm_arraysize(n, kint, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_generate_fm_minplus(int num, int n, int kint, int markov, int option, double K, double* out_vv, struct fm_env* env)
 def generate_fm_minplus(num, n, kint, markov, option, K, env):
     trace( "int py_generate_fm_minplus(int num, int n, int kint, int markov, int option, double K, double* out_vv, struct fm_env* env)")
@@ -1030,7 +1030,7 @@ def generate_fm_minplus(num, n, kint, markov, option, K, env):
     return yy, pout_vvnp, length
 
 
-# Generated python wrapper for:
+
 #    int py_generate_fm_2additive_convex(int num, int n,  double* out_vv)
 def generate_fm_2additive_convex(num, n):
     trace( "int py_generate_fm_2additive_convex(int num, int n,  double* vv)")
@@ -1040,7 +1040,7 @@ def generate_fm_2additive_convex(num, n):
     return yy, pout_vvnp, length
 
 
-# Generated python wrapper for:
+
 #    int py_generate_fm_2additive_convex_withsomeindependent(int num, int n, double* out_vv)
 def generate_fm_2additive_convex_withsomeindependent(num, n):
     trace( "int py_generate_fm_2additive_convex_withsomeindependent(int num, int n, double* vv)")
@@ -1050,7 +1050,7 @@ def generate_fm_2additive_convex_withsomeindependent(num, n):
     return yy, pout_vvnp, length
 
 
-# Generated python wrapper for:
+
 #    void py_prepare_fm_sparse(int n, int tupsize, int* tuples, struct fm_env_sparse* out_env)
 def prepare_fm_sparse( n, tupsize):
     try:
@@ -1063,7 +1063,7 @@ def prepare_fm_sparse( n, tupsize):
         raise
 
 
-# Generated python wrapper for:
+
 #    void py_free_fm_sparse( struct fm_env_sparse* env)
 def free_fm_sparse(env_sparse):
     try:
@@ -1073,7 +1073,7 @@ def free_fm_sparse(env_sparse):
     except ValueError:
         raise
 
-# Generated python wrapper for:
+
 #    int py_tuple_cardinality_sparse(int i, struct fm_env_sparse* env)
 def tuple_cardinality_sparse(i, env):
     trace( "int py_tuple_cardinality_sparse(int i, struct fm_env_sparse* env)")
@@ -1081,7 +1081,7 @@ def tuple_cardinality_sparse(i, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_get_num_tuples(struct fm_env_sparse* env)
 def get_num_tuples(env):
     trace( "int py_get_num_tuples(struct fm_env_sparse* env)")
@@ -1089,7 +1089,7 @@ def get_num_tuples(env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_get_sizearray_tuples(struct fm_env_sparse* env)
 def get_sizearray_tuples(env):
     trace( "int py_get_sizearray_tuples(struct fm_env_sparse* env)")
@@ -1097,7 +1097,7 @@ def get_sizearray_tuples(env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_is_inset_sparse(int A, int card, int i, struct fm_env_sparse* env)
 def is_inset_sparse(A, card, i, env):
     trace( "int py_is_inset_sparse(int A, int card, int i, struct fm_env_sparse* env)")
@@ -1105,7 +1105,7 @@ def is_inset_sparse(A, card, i, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int py_is_subset_sparse(int A, int cardA, int B, int cardB, struct fm_env_sparse* env)
 def is_subset_sparse(A, cardA, B, cardB, env):
     trace( "int py_is_subset_sparse(int A, int cardA, int B, int cardB, struct fm_env_sparse* env)")
@@ -1113,7 +1113,7 @@ def is_subset_sparse(A, cardA, B, cardB, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    double py_min_subset_sparse(double* x, int n, int S, int cardS, struct fm_env_sparse* env)
 def min_subset_sparse(x, n, S, cardS, env):
     trace( "double py_min_subset_sparse(double* x, int n, int S, int cardS, struct fm_env_sparse* env)")
@@ -1122,7 +1122,7 @@ def min_subset_sparse(x, n, S, cardS, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    double py_max_subset_sparse(double* x, int n, int S, int cardS, struct fm_env_sparse* env)
 def max_subset_sparse(x, n, S, cardS, env):
     trace( "double py_max_subset_sparse(double* x, int n, int S, int cardS, struct fm_env_sparse* env)")
@@ -1131,7 +1131,7 @@ def max_subset_sparse(x, n, S, cardS, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    double py_ChoquetMob_sparse(double* x, int n, struct fm_env_sparse* env)
 def ChoquetMob_sparse(x, env):
     trace( "double py_ChoquetMob_sparse(double* x, int n, struct fm_env_sparse* env)")
@@ -1141,7 +1141,7 @@ def ChoquetMob_sparse(x, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    void py_add_tuple_sparse(int tupsize, int* tuple, double v, struct fm_env_sparse* env)
 def add_tuple_sparse(tuple, v, env):
     trace( "void py_add_tuple_sparse(int tupsize, int* tuple, double v, struct fm_env_sparse* env)")
@@ -1151,7 +1151,7 @@ def add_tuple_sparse(tuple, v, env):
     fm.py_add_tuple_sparse( tupsize, ptuple, v, env)
 
 
-# Generated python wrapper for:
+
 #    void py_ShapleyMob_sparse(double* out_v, int n, struct fm_env_sparse* env)
 def ShapleyMob_sparse(n, env):
     trace( "void py_ShapleyMob_sparse(double* out_v, int n, struct fm_env_sparse* env)")
@@ -1160,7 +1160,7 @@ def ShapleyMob_sparse(n, env):
     return pout_vnp
 
 
-# Generated python wrapper for:
+
 #    void py_BanzhafMob_sparse(double* out_v, int n, struct fm_env_sparse* env)
 def BanzhafMob_sparse(n, env):
     trace( "void py_BanzhafMob_sparse(double* out_v, int n, struct fm_env_sparse* env)")
@@ -1170,7 +1170,7 @@ def BanzhafMob_sparse(n, env):
 
 
 
-# Generated python wrapper for:
+
 #    void py_populate_fm_2add_sparse(double* singletons, int numpairs, double* pairs, int* indicesp1, int* indicesp2, struct fm_env_sparse* env)
 def populate_fm_2add_sparse(singletons, numpairs, pairs, indicesp1, indicesp2, env):
     trace( "void py_populate_fm_2add_sparse(double* singletons, int numpairs, double* pairs, int* indicesp1, int* indicesp2, struct fm_env_sparse* env)")
@@ -1181,14 +1181,14 @@ def populate_fm_2add_sparse(singletons, numpairs, pairs, indicesp1, indicesp2, e
     fm.py_populate_fm_2add_sparse( psingletons, numpairs, ppairs, pindicesp1, pindicesp2, env)
 
 
-# Generated python wrapper for:
+
 #    void py_add_pair_sparse(int i, int j, double v, struct fm_env_sparse* env)
 def add_pair_sparse(i, j, v, env):
     trace( "void py_add_pair_sparse(int i, int j, double v, struct fm_env_sparse* env)")
     fm.py_add_pair_sparse( i, j, v, env)
 
 
-# Generated python wrapper for:
+
 #    void py_populate_fm_2add_sparse_from2add(int n, double* v, struct fm_env_sparse* env)
 def populate_fm_2add_sparse_from2add(n, v, env):
     trace( "void py_populate_fm_2add_sparse_from2add(int n, double* v, struct fm_env_sparse* env)")
@@ -1196,7 +1196,7 @@ def populate_fm_2add_sparse_from2add(n, v, env):
     fm.py_populate_fm_2add_sparse_from2add( n, pv, env)
 
 
-# Generated python wrapper for:
+
 #    void py_expand_2add_full(double* out_v, struct fm_env_sparse* env)
 def expand_2add_full(n, env):
     trace( "void py_expand_2add_full(double* out_v, struct fm_env_sparse* env)")
@@ -1205,7 +1205,7 @@ def expand_2add_full(n, env):
     return pout_vnp
 
 
-# Generated python wrapper for:
+
 #    void py_expand_sparse_full(double* v, struct fm_env_sparse* env)
 def expand_sparse_full(v, env):
     trace( "void py_expand_sparse_full(double* v, struct fm_env_sparse* env)")
@@ -1213,7 +1213,7 @@ def expand_sparse_full(v, env):
     fm.py_expand_sparse_full( pv, env)
 
 
-# Generated python wrapper for:
+
 #    void py_sparse_get_singletons(int n, double* out_v, struct fm_env_sparse* env)
 def sparse_get_singletons(n, env):
     trace( "void py_sparse_get_singletons(int n, double* out_v, struct fm_env_sparse* env)")
@@ -1222,7 +1222,7 @@ def sparse_get_singletons(n, env):
     return pout_vnp
 
 
-# Generated python wrapper for:
+
 #    int py_sparse_get_pairs(int* out_pairs, double* out_v, struct fm_env_sparse* env)
 def sparse_get_pairs(n, env):
     trace( "int py_sparse_get_pairs(int* out_pairs, double* out_v, struct fm_env_sparse* env)")
@@ -1232,7 +1232,7 @@ def sparse_get_pairs(n, env):
     return pout_pairsnp, pout_vnp
 
 
-# Generated python wrapper for:
+
 #    int py_sparse_get_tuples(int* out_tuples, double* out_v, struct fm_env_sparse* env)
 def sparse_get_tuples(env):
     trace( "int py_sparse_get_tuples(int* out_tuples, double* out_v, struct fm_env_sparse* env)")
@@ -1244,7 +1244,7 @@ def sparse_get_tuples(env):
     return pout_tuplesnp, pout_vnp
 
 
-# Generated python wrapper for:
+
 #    int   py_generate_fm_2additive_convex_sparse(int n, struct fm_env_sparse* env)
 def generate_fm_2additive_convex_sparse(n, env):
     trace( "int   py_generate_fm_2additive_convex_sparse(int n, struct fm_env_sparse* env)")
@@ -1252,7 +1252,7 @@ def generate_fm_2additive_convex_sparse(n, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    int   py_generate_fm_kadditive_convex_sparse(int n, int k, int nonzero, struct fm_env_sparse* env)
 def generate_fm_kadditive_convex_sparse(n, k, nonzero, env):
     trace( "int   py_generate_fm_kadditive_convex_sparse(int n, int k, int nonzero, struct fm_env_sparse* env)")
@@ -1260,7 +1260,7 @@ def generate_fm_kadditive_convex_sparse(n, k, nonzero, env):
     return yy
 
 
-# Generated python wrapper for:
+
 #    void py_Nonmodularityindex_sparse(double* out_w, int n, struct fm_env_sparse* env)
 def Nonmodularityindex_sparse(n, env):
     trace( "void py_Nonmodularityindex_sparse(double* out_w, int n, struct fm_env_sparse* env)")
