@@ -68,7 +68,9 @@ print("Sugeno integral of ",x,  " is ",z)
 
 
 fm.py_fm_free( env);
-n=8
+
+
+n=3
 fm.py_fm_init(n,  env);
 
 # Test wrapper for:
@@ -77,7 +79,7 @@ v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
 w = 0
 out_Mob = np.zeros( len( v),float);
 pout_Mob = ffi.cast("double *", out_Mob.ctypes.data);
-# w = fm.py_Interaction( pout_Mob, v, env)
+w = fm.py_Interaction( pout_Mob, v, env)
 print( "v: ", v)
 print( "w: ", w)
 
